@@ -9,6 +9,7 @@ __all__ =[
     'findPhone',
     'Phone',
     'call',
+    'callInfo',
     'answer',
     'drop',
     'hold',
@@ -22,6 +23,8 @@ __all__ =[
     'macro',
     'sendMessage',
     'sendRawMessage',
+    'startMonitor',
+    'stopMonitor',
     'migrate',
     'listResource',
     'getResource',
